LinearDimension — csdmpy 0.1.1 documentation

# LinearDimension

class `csdmpy.dimensions.linear.` `LinearDimension`(count, increment, complex_fft=False, **kwargs)

  Bases: `csdmpy.dimensions.quantitative.BaseQuantitativeDimension`

  LinearDimension class.

  Warning

  This class should not be used directly. Instead, use the `CSDM` object to access the attributes and methods of this class. See example, Linearly Sampled Dimension.

  The class returns an object which represents a physical dimension, sampled uniformly along a grid dimension. Let \(m_k\) be the increment, \(N_k \ge 1\) be the number of points, \(c_k\) be the reference offset, and \(o_k\) be the origin offset along the \(k^{th}\) grid dimension, then the coordinates along the grid dimension are given as

  \[\mathbf{X}_k^\mathrm{ref} = [m_k j ]_{j=0}^{N_k-1} - c_k \mathbf{1},\]
  \[\mathbf{X}_k^\mathrm{abs} = \mathbf{X}_k^\mathrm{ref} + o_k \mathbf{1},\]

  where \(\mathbf{X}_k^\mathrm{ref}\) is an ordered array of the reference controlled variable coordinates, \(\mathbf{X}_k^\mathrm{abs}\) is an ordered array of the absolute controlled variable coordinates, and \(\mathbf{1}\) is an array of ones.

  Attributes Summary

  `increment` | Increment of the grid points along the linear dimension.
  `complex_fft` | If True, orders the coordinates according to FFT output order.

  Attributes Documentation

  `increment`

    Increment of the grid points along the linear dimension.

  `complex_fft`

    If True, orders the coordinates according to FFT output order.